<?php

namespace FSPoster\App\Pages\Accounts\Controllers;

use FSPoster\App\Providers\Pages;
use FSPoster\App\Providers\Helper;
use FSPoster\App\Providers\Request;

class Main
{
	private function load_assets ()
	{
		wp_register_script( 'fsp-accounts', Pages::asset( 'Accounts', 'js/fsp-accounts.js' ), [
			'jquery',
			'fsp'
		], NULL );
		wp_enqueue_script( 'fsp-accounts' );

		wp_enqueue_style( 'fsp-accounts', Pages::asset( 'Accounts', 'css/fsp-accounts.css' ), [ 'fsp-ui' ], NULL );
	}

	public function index ()
	{
		$this->load_assets();

		$activeTab          = Request::get( 'tab', 'fb', 'string' );
		$filter             = Request::get( 'filter_by', '', [
			'all',
			'active',
			'inactive',
			'visible',
			'hidden',
			'failed'
		] );
		$fsp_accounts_count = Pages::action( 'Accounts', 'get_counts' );

		if ( ! empty( $filter ) )
		{
			Helper::setOption( 'accounts_default_filter_' . get_current_user_id(), $filter );
		}
		else
		{
			$filter = Helper::getOption( 'accounts_default_filter_' . get_current_user_id(), 'visible' );
		}

		if ( $activeTab === 'telegram' )
		{
			$button_text = fsp__( 'ADD A BOT' );
		}
		else if ( $activeTab === 'wordpress' )
		{
			$button_text = fsp__( 'ADD A SITE' );
		}
		else
		{
			$button_text = fsp__( 'ADD AN ACCOUNT' );
		}

		Pages::view( 'Accounts', 'index', [
			'accounts_count' => $fsp_accounts_count,
			'active_tab'     => $activeTab,
			'button_text'    => $button_text,
			'filter'         => $filter
		] );
	}
}